@@ -38,6 +38,11 @@ class Abstract_DB(ABC):
         return self.fetch_all(sql)
 
     def get_objects(self, key):
-        logger.info(f"Getting objects for key {key}")
         sql = get_sql(settings.objs_sql).format(KEY=key)
-        yield from self.select(sql)
+        objects = self.select(sql)
+        if len(objects) > 0:
+            logger.info(f"Found {len(objects)} objects for key {key}")
+        else:
+            logger.error(f"Found zero objects for key {key}")
+        for o in objects:
+            yield o
